"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class BenefitGrantPropertiesTypedDict(TypedDict):
    r"""Properties for a benefit grant."""


class BenefitGrantProperties(BaseModel):
    r"""Properties for a benefit grant."""
