"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class FileServiceTypes(str, Enum):
    DOWNLOADABLE = "downloadable"
    PRODUCT_MEDIA = "product_media"
    ORGANIZATION_AVATAR = "organization_avatar"
