"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .advertisementcampaign import AdvertisementCampaign, AdvertisementCampaignTypedDict
from .advertisementcampaignlistresource import (
    AdvertisementCampaignListResource,
    AdvertisementCampaignListResourceTypedDict,
)
from .advertisements_getop import (
    AdvertisementsGetRequest,
    AdvertisementsGetRequestTypedDict,
)
from .advertisements_listop import (
    AdvertisementsListRequest,
    AdvertisementsListRequestTypedDict,
    AdvertisementsListResponse,
    AdvertisementsListResponseTypedDict,
)
from .advertisementsortproperty import AdvertisementSortProperty
from .alreadycanceledsubscription import (
    AlreadyCanceledSubscription,
    AlreadyCanceledSubscriptionData,
    AlreadyCanceledSubscriptionType,
)
from .article import Article, ArticleTypedDict
from .articlebyline import ArticleByline
from .articlecreate import (
    ArticleCreate,
    ArticleCreateArticleByline,
    ArticleCreateArticleVisibility,
    ArticleCreateTypedDict,
)
from .articlepreview import ArticlePreview, ArticlePreviewTypedDict
from .articlereceivers import ArticleReceivers, ArticleReceiversTypedDict
from .articles_deleteop import ArticlesDeleteRequest, ArticlesDeleteRequestTypedDict
from .articles_getop import ArticlesGetRequest, ArticlesGetRequestTypedDict
from .articles_listop import (
    ArticleVisibilityFilter,
    ArticleVisibilityFilterTypedDict,
    ArticlesListQueryParamOrganizationIDFilter,
    ArticlesListQueryParamOrganizationIDFilterTypedDict,
    ArticlesListRequest,
    ArticlesListRequestTypedDict,
    ArticlesListResponse,
    ArticlesListResponseTypedDict,
)
from .articles_previewop import ArticlesPreviewRequest, ArticlesPreviewRequestTypedDict
from .articles_receiversop import (
    ArticlesReceiversRequest,
    ArticlesReceiversRequestTypedDict,
)
from .articles_sendop import ArticlesSendRequest, ArticlesSendRequestTypedDict
from .articles_updateop import ArticlesUpdateRequest, ArticlesUpdateRequestTypedDict
from .articleupdate import ArticleUpdate, ArticleUpdateTypedDict
from .articlevisibility import ArticleVisibility
from .assignee import Assignee, AssigneeTypedDict
from .author import Author, AuthorTypedDict
from .benefitads import BenefitAds, BenefitAdsType, BenefitAdsTypedDict
from .benefitadscreate import (
    BenefitAdsCreate,
    BenefitAdsCreateType,
    BenefitAdsCreateTypedDict,
)
from .benefitadsproperties import BenefitAdsProperties, BenefitAdsPropertiesTypedDict
from .benefitadssubscriber import (
    BenefitAdsSubscriber,
    BenefitAdsSubscriberType,
    BenefitAdsSubscriberTypedDict,
)
from .benefitadsupdate import (
    BenefitAdsUpdate,
    BenefitAdsUpdateType,
    BenefitAdsUpdateTypedDict,
)
from .benefitarticles import (
    BenefitArticles,
    BenefitArticlesType,
    BenefitArticlesTypedDict,
)
from .benefitarticlesproperties import (
    BenefitArticlesProperties,
    BenefitArticlesPropertiesTypedDict,
)
from .benefitarticlessubscriber import (
    BenefitArticlesSubscriber,
    BenefitArticlesSubscriberTypedDict,
    Type,
)
from .benefitarticlessubscriberproperties import (
    BenefitArticlesSubscriberProperties,
    BenefitArticlesSubscriberPropertiesTypedDict,
)
from .benefitarticlesupdate import (
    BenefitArticlesUpdate,
    BenefitArticlesUpdateType,
    BenefitArticlesUpdateTypedDict,
)
from .benefitbase import BenefitBase, BenefitBaseTypedDict
from .benefitcustom import BenefitCustom, BenefitCustomType, BenefitCustomTypedDict
from .benefitcustomcreate import (
    BenefitCustomCreate,
    BenefitCustomCreateType,
    BenefitCustomCreateTypedDict,
)
from .benefitcustomproperties import (
    BenefitCustomProperties,
    BenefitCustomPropertiesTypedDict,
)
from .benefitcustomsubscriber import (
    BenefitCustomSubscriber,
    BenefitCustomSubscriberType,
    BenefitCustomSubscriberTypedDict,
)
from .benefitcustomsubscriberproperties import (
    BenefitCustomSubscriberProperties,
    BenefitCustomSubscriberPropertiesTypedDict,
)
from .benefitcustomupdate import (
    BenefitCustomUpdate,
    BenefitCustomUpdateType,
    BenefitCustomUpdateTypedDict,
)
from .benefitdiscord_input import (
    BenefitDiscordInput,
    BenefitDiscordInputType,
    BenefitDiscordInputTypedDict,
)
from .benefitdiscord_output import (
    BenefitDiscordOutput,
    BenefitDiscordOutputType,
    BenefitDiscordOutputTypedDict,
)
from .benefitdiscordcreate import (
    BenefitDiscordCreate,
    BenefitDiscordCreateType,
    BenefitDiscordCreateTypedDict,
)
from .benefitdiscordcreateproperties import (
    BenefitDiscordCreateProperties,
    BenefitDiscordCreatePropertiesTypedDict,
)
from .benefitdiscordproperties_input import (
    BenefitDiscordPropertiesInput,
    BenefitDiscordPropertiesInputTypedDict,
)
from .benefitdiscordproperties_output import (
    BenefitDiscordPropertiesOutput,
    BenefitDiscordPropertiesOutputTypedDict,
)
from .benefitdiscordsubscriber import (
    BenefitDiscordSubscriber,
    BenefitDiscordSubscriberType,
    BenefitDiscordSubscriberTypedDict,
)
from .benefitdiscordsubscriberproperties import (
    BenefitDiscordSubscriberProperties,
    BenefitDiscordSubscriberPropertiesTypedDict,
)
from .benefitdiscordupdate import (
    BenefitDiscordUpdate,
    BenefitDiscordUpdateType,
    BenefitDiscordUpdateTypedDict,
)
from .benefitdownloadables import (
    BenefitDownloadables,
    BenefitDownloadablesType,
    BenefitDownloadablesTypedDict,
)
from .benefitdownloadablescreate import (
    BenefitDownloadablesCreate,
    BenefitDownloadablesCreateType,
    BenefitDownloadablesCreateTypedDict,
)
from .benefitdownloadablescreateproperties import (
    BenefitDownloadablesCreateProperties,
    BenefitDownloadablesCreatePropertiesTypedDict,
)
from .benefitdownloadablesproperties import (
    BenefitDownloadablesProperties,
    BenefitDownloadablesPropertiesTypedDict,
)
from .benefitdownloadablessubscriber import (
    BenefitDownloadablesSubscriber,
    BenefitDownloadablesSubscriberType,
    BenefitDownloadablesSubscriberTypedDict,
)
from .benefitdownloadablessubscriberproperties import (
    BenefitDownloadablesSubscriberProperties,
    BenefitDownloadablesSubscriberPropertiesTypedDict,
)
from .benefitdownloadablesupdate import (
    BenefitDownloadablesUpdate,
    BenefitDownloadablesUpdateType,
    BenefitDownloadablesUpdateTypedDict,
)
from .benefitgithubrepository import (
    BenefitGitHubRepository,
    BenefitGitHubRepositoryType,
    BenefitGitHubRepositoryTypedDict,
)
from .benefitgithubrepositorycreate import (
    BenefitGitHubRepositoryCreate,
    BenefitGitHubRepositoryCreateType,
    BenefitGitHubRepositoryCreateTypedDict,
)
from .benefitgithubrepositorycreateproperties import (
    BenefitGitHubRepositoryCreateProperties,
    BenefitGitHubRepositoryCreatePropertiesPermission,
    BenefitGitHubRepositoryCreatePropertiesTypedDict,
)
from .benefitgithubrepositoryproperties import (
    BenefitGitHubRepositoryProperties,
    BenefitGitHubRepositoryPropertiesTypedDict,
    Permission,
)
from .benefitgithubrepositorysubscriber import (
    BenefitGitHubRepositorySubscriber,
    BenefitGitHubRepositorySubscriberType,
    BenefitGitHubRepositorySubscriberTypedDict,
)
from .benefitgithubrepositorysubscriberproperties import (
    BenefitGitHubRepositorySubscriberProperties,
    BenefitGitHubRepositorySubscriberPropertiesTypedDict,
)
from .benefitgithubrepositoryupdate import (
    BenefitGitHubRepositoryUpdate,
    BenefitGitHubRepositoryUpdateType,
    BenefitGitHubRepositoryUpdateTypedDict,
)
from .benefitgrant import BenefitGrant, BenefitGrantTypedDict
from .benefitgrantads import BenefitGrantAds, BenefitGrantAdsTypedDict
from .benefitgrantadsproperties import (
    BenefitGrantAdsProperties,
    BenefitGrantAdsPropertiesTypedDict,
)
from .benefitgrantlicensekeys import (
    BenefitGrantLicenseKeys,
    BenefitGrantLicenseKeysTypedDict,
)
from .benefitgrantlicensekeysproperties import (
    BenefitGrantLicenseKeysProperties,
    BenefitGrantLicenseKeysPropertiesTypedDict,
)
from .benefitgrantproperties import (
    BenefitGrantProperties,
    BenefitGrantPropertiesTypedDict,
)
from .benefitlicensekeyactivationproperties import (
    BenefitLicenseKeyActivationProperties,
    BenefitLicenseKeyActivationPropertiesTypedDict,
)
from .benefitlicensekeyexpirationproperties import (
    BenefitLicenseKeyExpirationProperties,
    BenefitLicenseKeyExpirationPropertiesTypedDict,
    Timeframe,
)
from .benefitlicensekeys_input import (
    BenefitLicenseKeysInput,
    BenefitLicenseKeysInputType,
    BenefitLicenseKeysInputTypedDict,
)
from .benefitlicensekeys_output import (
    BenefitLicenseKeysOutput,
    BenefitLicenseKeysOutputType,
    BenefitLicenseKeysOutputTypedDict,
)
from .benefitlicensekeyscreate import (
    BenefitLicenseKeysCreate,
    BenefitLicenseKeysCreateType,
    BenefitLicenseKeysCreateTypedDict,
)
from .benefitlicensekeyscreateproperties import (
    BenefitLicenseKeysCreateProperties,
    BenefitLicenseKeysCreatePropertiesTypedDict,
)
from .benefitlicensekeysproperties import (
    BenefitLicenseKeysProperties,
    BenefitLicenseKeysPropertiesTypedDict,
)
from .benefitlicensekeyssubscriber import (
    BenefitLicenseKeysSubscriber,
    BenefitLicenseKeysSubscriberType,
    BenefitLicenseKeysSubscriberTypedDict,
)
from .benefitlicensekeyssubscriberproperties import (
    BenefitLicenseKeysSubscriberProperties,
    BenefitLicenseKeysSubscriberPropertiesTypedDict,
)
from .benefitlicensekeysupdate import (
    BenefitLicenseKeysUpdate,
    BenefitLicenseKeysUpdateType,
    BenefitLicenseKeysUpdateTypedDict,
)
from .benefits_createop import (
    BenefitsCreateBenefitCreate,
    BenefitsCreateBenefitCreateTypedDict,
    BenefitsCreateResponseBenefitsCreate,
    BenefitsCreateResponseBenefitsCreateTypedDict,
)
from .benefits_deleteop import BenefitsDeleteRequest, BenefitsDeleteRequestTypedDict
from .benefits_getop import (
    BenefitsGetRequest,
    BenefitsGetRequestTypedDict,
    BenefitsGetResponseBenefitsGet,
    BenefitsGetResponseBenefitsGetTypedDict,
)
from .benefits_grantsop import (
    BenefitsGrantsRequest,
    BenefitsGrantsRequestTypedDict,
    BenefitsGrantsResponse,
    BenefitsGrantsResponseTypedDict,
)
from .benefits_listop import (
    BenefitsListQueryParamOrganizationIDFilter,
    BenefitsListQueryParamOrganizationIDFilterTypedDict,
    BenefitsListRequest,
    BenefitsListRequestTypedDict,
    BenefitsListResponse,
    BenefitsListResponseTypedDict,
    QueryParamBenefitTypeFilter,
    QueryParamBenefitTypeFilterTypedDict,
)
from .benefits_updateop import (
    BenefitsUpdateBenefitUpdate,
    BenefitsUpdateBenefitUpdateTypedDict,
    BenefitsUpdateRequest,
    BenefitsUpdateRequestTypedDict,
    BenefitsUpdateResponseBenefitsUpdate,
    BenefitsUpdateResponseBenefitsUpdateTypedDict,
)
from .benefittype import BenefitType
from .bylineprofile import BylineProfile, BylineProfileTypedDict
from .checkout import Checkout, CheckoutTypedDict
from .checkoutcreate import CheckoutCreate, CheckoutCreateTypedDict
from .checkouts_getop import CheckoutsGetRequest, CheckoutsGetRequestTypedDict
from .currencyamount import CurrencyAmount, CurrencyAmountTypedDict
from .donation_input import DonationInput, DonationInputTypedDict, Donor, DonorTypedDict
from .donationorganization import DonationOrganization, DonationOrganizationTypedDict
from .donationuser import DonationUser, DonationUserTypedDict
from .downloadablefilecreate import (
    DownloadableFileCreate,
    DownloadableFileCreateService,
    DownloadableFileCreateTypedDict,
)
from .downloadablefileread import (
    DownloadableFileRead,
    DownloadableFileReadService,
    DownloadableFileReadTypedDict,
)
from .downloadableread import DownloadableRead, DownloadableReadTypedDict
from .existingproductprice import ExistingProductPrice, ExistingProductPriceTypedDict
from .external_organizations_listop import (
    ExternalOrganizationsListQueryParamOrganizationIDFilter,
    ExternalOrganizationsListQueryParamOrganizationIDFilterTypedDict,
    ExternalOrganizationsListRequest,
    ExternalOrganizationsListRequestTypedDict,
    ExternalOrganizationsListResponse,
    ExternalOrganizationsListResponseTypedDict,
    PlatformFilter,
    PlatformFilterTypedDict,
    RepositoryNameFilter,
    RepositoryNameFilterTypedDict,
)
from .externalorganization import ExternalOrganization, ExternalOrganizationTypedDict
from .externalorganizationsortproperty import ExternalOrganizationSortProperty
from .filedownload import FileDownload, FileDownloadTypedDict
from .filenotfound import FileNotFound, FileNotFoundData, FileNotFoundType
from .filepatch import FilePatch, FilePatchTypedDict
from .files_createop import FilesCreateFileCreate, FilesCreateFileCreateTypedDict
from .files_deleteop import FilesDeleteRequest, FilesDeleteRequestTypedDict
from .files_listop import (
    FilesListRequest,
    FilesListRequestTypedDict,
    FilesListResponse,
    FilesListResponseTypedDict,
)
from .files_updateop import (
    FilesUpdateRequest,
    FilesUpdateRequestTypedDict,
    FilesUpdateResponseFilesUpdate,
    FilesUpdateResponseFilesUpdateTypedDict,
)
from .files_uploadedop import (
    FilesUploadedRequest,
    FilesUploadedRequestTypedDict,
    FilesUploadedResponseFilesUploaded,
    FilesUploadedResponseFilesUploadedTypedDict,
)
from .fileservicetypes import FileServiceTypes
from .fileupload import FileUpload, FileUploadTypedDict
from .fileuploadcompleted import FileUploadCompleted, FileUploadCompletedTypedDict
from .funding import Funding, FundingTypedDict
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .introspecttokenresponse import (
    IntrospectTokenResponse,
    IntrospectTokenResponseTokenType,
    IntrospectTokenResponseTypedDict,
)
from .issue_input import IssueInput, IssueInputTypedDict
from .label import Label, LabelTypedDict
from .license_keys_get_activationop import (
    LicenseKeysGetActivationRequest,
    LicenseKeysGetActivationRequestTypedDict,
)
from .license_keys_getop import LicenseKeysGetRequest, LicenseKeysGetRequestTypedDict
from .license_keys_listop import (
    LicenseKeysListQueryParamOrganizationIDFilter,
    LicenseKeysListQueryParamOrganizationIDFilterTypedDict,
    LicenseKeysListRequest,
    LicenseKeysListRequestTypedDict,
    LicenseKeysListResponse,
    LicenseKeysListResponseTypedDict,
)
from .license_keys_updateop import (
    LicenseKeysUpdateRequest,
    LicenseKeysUpdateRequestTypedDict,
)
from .licensekeyactivate import (
    LicenseKeyActivate,
    LicenseKeyActivateConditions,
    LicenseKeyActivateConditionsTypedDict,
    LicenseKeyActivateMeta,
    LicenseKeyActivateMetaTypedDict,
    LicenseKeyActivateTypedDict,
)
from .licensekeyactivationbase import (
    LicenseKeyActivationBase,
    LicenseKeyActivationBaseTypedDict,
    Meta,
    MetaTypedDict,
)
from .licensekeyactivationread import (
    LicenseKeyActivationRead,
    LicenseKeyActivationReadMeta,
    LicenseKeyActivationReadMetaTypedDict,
    LicenseKeyActivationReadTypedDict,
)
from .licensekeydeactivate import LicenseKeyDeactivate, LicenseKeyDeactivateTypedDict
from .licensekeyread import LicenseKeyRead, LicenseKeyReadTypedDict
from .licensekeystatus import LicenseKeyStatus
from .licensekeyupdate import LicenseKeyUpdate, LicenseKeyUpdateTypedDict
from .licensekeyvalidate import (
    Conditions,
    ConditionsTypedDict,
    LicenseKeyValidate,
    LicenseKeyValidateTypedDict,
)
from .licensekeywithactivations import (
    LicenseKeyWithActivations,
    LicenseKeyWithActivationsTypedDict,
)
from .listresource_article_ import ListResourceArticle, ListResourceArticleTypedDict
from .listresource_benefit_ import (
    Benefit,
    BenefitTypedDict,
    ListResourceBenefit,
    ListResourceBenefitTypedDict,
)
from .listresource_benefitgrant_ import (
    ListResourceBenefitGrant,
    ListResourceBenefitGrantTypedDict,
)
from .listresource_downloadableread_ import (
    ListResourceDownloadableRead,
    ListResourceDownloadableReadTypedDict,
)
from .listresource_externalorganization_ import (
    ListResourceExternalOrganization,
    ListResourceExternalOrganizationTypedDict,
)
from .listresource_fileread_ import (
    FileRead,
    FileReadTypedDict,
    ListResourceFileRead,
    ListResourceFileReadTypedDict,
)
from .listresource_licensekeyread_ import (
    ListResourceLicenseKeyRead,
    ListResourceLicenseKeyReadTypedDict,
)
from .listresource_oauth2client_ import (
    ListResourceOAuth2Client,
    ListResourceOAuth2ClientTypedDict,
)
from .listresource_order_ import ListResourceOrder, ListResourceOrderTypedDict
from .listresource_organization_ import (
    ListResourceOrganization,
    ListResourceOrganizationTypedDict,
)
from .listresource_product_ import ListResourceProduct, ListResourceProductTypedDict
from .listresource_repository_ import (
    ListResourceRepository,
    ListResourceRepositoryTypedDict,
)
from .listresource_subscription_ import (
    ListResourceSubscription,
    ListResourceSubscriptionTypedDict,
)
from .listresource_useradvertisementcampaign_ import (
    ListResourceUserAdvertisementCampaign,
    ListResourceUserAdvertisementCampaignTypedDict,
)
from .listresource_userbenefit_ import (
    ListResourceUserBenefit,
    ListResourceUserBenefitTypedDict,
    UserBenefit,
    UserBenefitTypedDict,
)
from .listresource_userorder_ import (
    ListResourceUserOrder,
    ListResourceUserOrderTypedDict,
)
from .listresource_usersubscription_ import (
    ListResourceUserSubscription,
    ListResourceUserSubscriptionTypedDict,
)
from .metric import Metric, MetricTypedDict
from .metricperiod import MetricPeriod, MetricPeriodTypedDict
from .metrics import Metrics, MetricsTypedDict
from .metrics_getop import (
    Interval,
    MetricsGetQueryParamOrganizationIDFilter,
    MetricsGetQueryParamOrganizationIDFilterTypedDict,
    MetricsGetQueryParamProductIDFilter,
    MetricsGetQueryParamProductIDFilterTypedDict,
    MetricsGetQueryParamProductPriceTypeFilter,
    MetricsGetQueryParamProductPriceTypeFilterTypedDict,
    MetricsGetRequest,
    MetricsGetRequestTypedDict,
)
from .metricsintervallimit import MetricsIntervalLimit, MetricsIntervalLimitTypedDict
from .metricsintervalslimits import (
    MetricsIntervalsLimits,
    MetricsIntervalsLimitsTypedDict,
)
from .metricslimits import MetricsLimits, MetricsLimitsTypedDict
from .metricsresponse import MetricsResponse, MetricsResponseTypedDict
from .metrictype import MetricType
from .notpermitted import NotPermitted, NotPermittedData, NotPermittedType
from .oauth2_clients_listop import (
    Oauth2ClientsListRequest,
    Oauth2ClientsListRequestTypedDict,
    Oauth2ClientsListResponse,
    Oauth2ClientsListResponseTypedDict,
)
from .oauth2_clients_oauth2_delete_clientop import (
    Oauth2ClientsOauth2DeleteClientRequest,
    Oauth2ClientsOauth2DeleteClientRequestTypedDict,
)
from .oauth2_clients_oauth2_get_clientop import (
    Oauth2ClientsOauth2GetClientRequest,
    Oauth2ClientsOauth2GetClientRequestTypedDict,
)
from .oauth2_clients_oauth2_update_clientop import (
    Oauth2ClientsOauth2UpdateClientRequest,
    Oauth2ClientsOauth2UpdateClientRequestTypedDict,
)
from .oauth2_introspect_tokenop import (
    Oauth2IntrospectTokenIntrospectTokenRequest,
    Oauth2IntrospectTokenIntrospectTokenRequestTypedDict,
    Oauth2IntrospectTokenTokenTypeHint,
)
from .oauth2_request_tokenop import (
    Oauth2RequestTokenRequestBody,
    Oauth2RequestTokenRequestBodyTypedDict,
)
from .oauth2_revoke_tokenop import (
    Oauth2RevokeTokenRevokeTokenRequest,
    Oauth2RevokeTokenRevokeTokenRequestTypedDict,
    TokenTypeHint,
)
from .oauth2_userinfoop import (
    Oauth2UserinfoResponseOauth2Userinfo,
    Oauth2UserinfoResponseOauth2UserinfoTypedDict,
)
from .oauth2client import (
    GrantTypes,
    OAuth2Client,
    OAuth2ClientTypedDict,
    ResponseTypes,
    TokenEndpointAuthMethod,
)
from .oauth2clientconfiguration import (
    OAuth2ClientConfiguration,
    OAuth2ClientConfigurationGrantTypes,
    OAuth2ClientConfigurationResponseTypes,
    OAuth2ClientConfigurationTokenEndpointAuthMethod,
    OAuth2ClientConfigurationTypedDict,
)
from .oauth2clientconfigurationupdate import (
    OAuth2ClientConfigurationUpdate,
    OAuth2ClientConfigurationUpdateGrantTypes,
    OAuth2ClientConfigurationUpdateResponseTypes,
    OAuth2ClientConfigurationUpdateTokenEndpointAuthMethod,
    OAuth2ClientConfigurationUpdateTypedDict,
)
from .onev1_1oauth2_1token_post_x_components_authorizationcodetokenrequest import (
    GrantType,
    Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequest,
    Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequestTypedDict,
)
from .onev1_1oauth2_1token_post_x_components_refreshtokenrequest import (
    Onev11oauth21tokenPostXComponentsRefreshTokenRequest,
    Onev11oauth21tokenPostXComponentsRefreshTokenRequestGrantType,
    Onev11oauth21tokenPostXComponentsRefreshTokenRequestTypedDict,
)
from .order_input import OrderInput, OrderInputTypedDict
from .order_output import OrderOutput, OrderOutputTypedDict
from .orderinvoice import OrderInvoice, OrderInvoiceTypedDict
from .orderproduct import OrderProduct, OrderProductTypedDict
from .orders_getop import OrdersGetRequest, OrdersGetRequestTypedDict
from .orders_invoiceop import OrdersInvoiceRequest, OrdersInvoiceRequestTypedDict
from .orders_listop import (
    OrdersListQueryParamOrganizationIDFilter,
    OrdersListQueryParamOrganizationIDFilterTypedDict,
    OrdersListQueryParamProductIDFilter,
    OrdersListQueryParamProductIDFilterTypedDict,
    OrdersListRequest,
    OrdersListRequestTypedDict,
    OrdersListResponse,
    OrdersListResponseTypedDict,
    QueryParamProductPriceTypeFilter,
    QueryParamProductPriceTypeFilterTypedDict,
    UserIDFilter,
    UserIDFilterTypedDict,
)
from .ordersortproperty import OrderSortProperty
from .ordersubscription import OrderSubscription, OrderSubscriptionTypedDict
from .orderuser import OrderUser, OrderUserTypedDict
from .organization_input import OrganizationInput, OrganizationInputTypedDict
from .organization_output import OrganizationOutput, OrganizationOutputTypedDict
from .organizationavatarfilecreate import (
    OrganizationAvatarFileCreate,
    OrganizationAvatarFileCreateService,
    OrganizationAvatarFileCreateTypedDict,
)
from .organizationavatarfileread import (
    OrganizationAvatarFileRead,
    OrganizationAvatarFileReadService,
    OrganizationAvatarFileReadTypedDict,
)
from .organizationcreate import OrganizationCreate, OrganizationCreateTypedDict
from .organizationfeaturesettings import (
    OrganizationFeatureSettings,
    OrganizationFeatureSettingsTypedDict,
)
from .organizationprofilesettings import (
    OrganizationProfileSettings,
    OrganizationProfileSettingsTypedDict,
)
from .organizations_getop import (
    OrganizationsGetRequest,
    OrganizationsGetRequestTypedDict,
)
from .organizations_listop import (
    OrganizationsListRequest,
    OrganizationsListRequestTypedDict,
    OrganizationsListResponse,
    OrganizationsListResponseTypedDict,
)
from .organizations_updateop import (
    OrganizationsUpdateRequest,
    OrganizationsUpdateRequestTypedDict,
)
from .organizationsortproperty import OrganizationSortProperty
from .organizationsubscribepromotesettings import (
    OrganizationSubscribePromoteSettings,
    OrganizationSubscribePromoteSettingsTypedDict,
)
from .organizationupdate import OrganizationUpdate, OrganizationUpdateTypedDict
from .pagination import Pagination, PaginationTypedDict
from .platforms import Platforms
from .pledge_input import PledgeInput, PledgeInputTypedDict
from .pledger import Pledger, PledgerTypedDict
from .pledgestate import PledgeState
from .pledgetype import PledgeType
from .product_input import (
    ProductInput,
    ProductInputBenefits,
    ProductInputBenefitsTypedDict,
    ProductInputTypedDict,
)
from .product_output import (
    ProductOutput,
    ProductOutputBenefits,
    ProductOutputBenefitsTypedDict,
    ProductOutputTypedDict,
)
from .productbenefitsupdate import ProductBenefitsUpdate, ProductBenefitsUpdateTypedDict
from .productmediafilecreate import (
    ProductMediaFileCreate,
    ProductMediaFileCreateService,
    ProductMediaFileCreateTypedDict,
)
from .productmediafileread_input import (
    ProductMediaFileReadInput,
    ProductMediaFileReadInputService,
    ProductMediaFileReadInputTypedDict,
)
from .productmediafileread_output import (
    ProductMediaFileReadOutput,
    ProductMediaFileReadOutputTypedDict,
    Service,
)
from .productonetimecreate import (
    Prices,
    PricesTypedDict,
    ProductOneTimeCreate,
    ProductOneTimeCreateTypedDict,
)
from .productprice_input import ProductPriceInput, ProductPriceInputTypedDict
from .productprice_output import ProductPriceOutput, ProductPriceOutputTypedDict
from .productpriceonetime import ProductPriceOneTime, ProductPriceOneTimeTypedDict
from .productpriceonetimecustom import (
    ProductPriceOneTimeCustom,
    ProductPriceOneTimeCustomAmountType,
    ProductPriceOneTimeCustomType,
    ProductPriceOneTimeCustomTypedDict,
)
from .productpriceonetimecustomcreate import (
    ProductPriceOneTimeCustomCreate,
    ProductPriceOneTimeCustomCreateAmountType,
    ProductPriceOneTimeCustomCreateType,
    ProductPriceOneTimeCustomCreateTypedDict,
)
from .productpriceonetimefixed import (
    ProductPriceOneTimeFixed,
    ProductPriceOneTimeFixedAmountType,
    ProductPriceOneTimeFixedType,
    ProductPriceOneTimeFixedTypedDict,
)
from .productpriceonetimefixedcreate import (
    ProductPriceOneTimeFixedCreate,
    ProductPriceOneTimeFixedCreateAmountType,
    ProductPriceOneTimeFixedCreateType,
    ProductPriceOneTimeFixedCreateTypedDict,
)
from .productpriceonetimefree import (
    ProductPriceOneTimeFree,
    ProductPriceOneTimeFreeAmountType,
    ProductPriceOneTimeFreeType,
    ProductPriceOneTimeFreeTypedDict,
)
from .productpriceonetimefreecreate import (
    ProductPriceOneTimeFreeCreate,
    ProductPriceOneTimeFreeCreateAmountType,
    ProductPriceOneTimeFreeCreateType,
    ProductPriceOneTimeFreeCreateTypedDict,
)
from .productpricerecurring_input import (
    ProductPriceRecurringInput,
    ProductPriceRecurringInputTypedDict,
)
from .productpricerecurring_output import (
    ProductPriceRecurringOutput,
    ProductPriceRecurringOutputTypedDict,
)
from .productpricerecurringcustom import (
    ProductPriceRecurringCustom,
    ProductPriceRecurringCustomAmountType,
    ProductPriceRecurringCustomType,
    ProductPriceRecurringCustomTypedDict,
)
from .productpricerecurringfixed import (
    AmountType,
    ProductPriceRecurringFixed,
    ProductPriceRecurringFixedType,
    ProductPriceRecurringFixedTypedDict,
)
from .productpricerecurringfixedcreate import (
    ProductPriceRecurringFixedCreate,
    ProductPriceRecurringFixedCreateAmountType,
    ProductPriceRecurringFixedCreateType,
    ProductPriceRecurringFixedCreateTypedDict,
)
from .productpricerecurringfree import (
    ProductPriceRecurringFree,
    ProductPriceRecurringFreeAmountType,
    ProductPriceRecurringFreeType,
    ProductPriceRecurringFreeTypedDict,
)
from .productpricerecurringfreecreate import (
    ProductPriceRecurringFreeCreate,
    ProductPriceRecurringFreeCreateAmountType,
    ProductPriceRecurringFreeCreateType,
    ProductPriceRecurringFreeCreateTypedDict,
)
from .productpricetype import ProductPriceType
from .productrecurringcreate import (
    ProductRecurringCreate,
    ProductRecurringCreatePrices,
    ProductRecurringCreatePricesTypedDict,
    ProductRecurringCreateTypedDict,
)
from .products_createop import (
    ProductsCreateProductCreate,
    ProductsCreateProductCreateTypedDict,
)
from .products_getop import ProductsGetRequest, ProductsGetRequestTypedDict
from .products_listop import (
    ProductsListQueryParamOrganizationIDFilter,
    ProductsListQueryParamOrganizationIDFilterTypedDict,
    ProductsListRequest,
    ProductsListRequestTypedDict,
    ProductsListResponse,
    ProductsListResponseTypedDict,
    QueryParamBenefitIDFilter,
    QueryParamBenefitIDFilterTypedDict,
)
from .products_update_benefitsop import (
    ProductsUpdateBenefitsRequest,
    ProductsUpdateBenefitsRequestTypedDict,
)
from .products_updateop import ProductsUpdateRequest, ProductsUpdateRequestTypedDict
from .productupdate import (
    ProductUpdate,
    ProductUpdatePrices,
    ProductUpdatePricesTypedDict,
    ProductUpdateTypedDict,
)
from .reactions import Reactions, ReactionsTypedDict
from .repositories_getop import RepositoriesGetRequest, RepositoriesGetRequestTypedDict
from .repositories_listop import (
    ExternalOrganizationNameFilter,
    ExternalOrganizationNameFilterTypedDict,
    QueryParamPlatformFilter,
    QueryParamPlatformFilterTypedDict,
    QueryParamRepositoryNameFilter,
    QueryParamRepositoryNameFilterTypedDict,
    RepositoriesListQueryParamOrganizationIDFilter,
    RepositoriesListQueryParamOrganizationIDFilterTypedDict,
    RepositoriesListRequest,
    RepositoriesListRequestTypedDict,
    RepositoriesListResponse,
    RepositoriesListResponseTypedDict,
)
from .repositories_updateop import (
    RepositoriesUpdateRequest,
    RepositoriesUpdateRequestTypedDict,
)
from .repository_input import RepositoryInput, RepositoryInputTypedDict
from .repository_output import RepositoryOutput, RepositoryOutputTypedDict
from .repositoryprofilesettings import (
    RepositoryProfileSettings,
    RepositoryProfileSettingsTypedDict,
)
from .repositoryprofilesettingsupdate import (
    RepositoryProfileSettingsUpdate,
    RepositoryProfileSettingsUpdateTypedDict,
)
from .repositorysortproperty import RepositorySortProperty
from .repositoryupdate import RepositoryUpdate, RepositoryUpdateTypedDict
from .resourcenotfound import (
    ResourceNotFound,
    ResourceNotFoundData,
    ResourceNotFoundType,
)
from .revoketokenresponse import RevokeTokenResponse, RevokeTokenResponseTypedDict
from .s3downloadurl import S3DownloadURL, S3DownloadURLTypedDict
from .s3filecreatemultipart import S3FileCreateMultipart, S3FileCreateMultipartTypedDict
from .s3filecreatepart import S3FileCreatePart, S3FileCreatePartTypedDict
from .s3fileuploadcompletedpart import (
    S3FileUploadCompletedPart,
    S3FileUploadCompletedPartTypedDict,
)
from .s3fileuploadmultipart import S3FileUploadMultipart, S3FileUploadMultipartTypedDict
from .s3fileuploadpart import S3FileUploadPart, S3FileUploadPartTypedDict
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .state import State
from .subscription_input import SubscriptionInput, SubscriptionInputTypedDict
from .subscription_output import SubscriptionOutput, SubscriptionOutputTypedDict
from .subscriptionrecurringinterval import SubscriptionRecurringInterval
from .subscriptions_exportop import (
    OrganizationID,
    OrganizationIDTypedDict,
    SubscriptionsExportRequest,
    SubscriptionsExportRequestTypedDict,
)
from .subscriptions_listop import (
    SubscriptionsListQueryParamOrganizationIDFilter,
    SubscriptionsListQueryParamOrganizationIDFilterTypedDict,
    SubscriptionsListQueryParamProductIDFilter,
    SubscriptionsListQueryParamProductIDFilterTypedDict,
    SubscriptionsListRequest,
    SubscriptionsListRequestTypedDict,
    SubscriptionsListResponse,
    SubscriptionsListResponseTypedDict,
)
from .subscriptionsortproperty import SubscriptionSortProperty
from .subscriptionstatus import SubscriptionStatus
from .subscriptionuser import SubscriptionUser, SubscriptionUserTypedDict
from .subtype import SubType
from .tokenresponse import TokenResponse, TokenResponseTypedDict, TokenType
from .unauthorized import Unauthorized, UnauthorizedData, UnauthorizedType
from .useradvertisementcampaign import (
    UserAdvertisementCampaign,
    UserAdvertisementCampaignTypedDict,
)
from .useradvertisementcampaigncreate import (
    UserAdvertisementCampaignCreate,
    UserAdvertisementCampaignCreateTypedDict,
)
from .useradvertisementcampaignenable import (
    UserAdvertisementCampaignEnable,
    UserAdvertisementCampaignEnableTypedDict,
)
from .useradvertisementcampaignupdate import (
    UserAdvertisementCampaignUpdate,
    UserAdvertisementCampaignUpdateTypedDict,
)
from .useradvertisementsortproperty import UserAdvertisementSortProperty
from .userbenefitsortproperty import UserBenefitSortProperty
from .userinfoorganization import UserInfoOrganization, UserInfoOrganizationTypedDict
from .userinfouser import UserInfoUser, UserInfoUserTypedDict
from .userorder import UserOrder, UserOrderTypedDict
from .userorderinvoice import UserOrderInvoice, UserOrderInvoiceTypedDict
from .userorderproduct import (
    BenefitsModel,
    BenefitsModelTypedDict,
    UserOrderProduct,
    UserOrderProductTypedDict,
)
from .userordersortproperty import UserOrderSortProperty
from .userordersubscription import UserOrderSubscription, UserOrderSubscriptionTypedDict
from .users_advertisements_deleteop import (
    UsersAdvertisementsDeleteRequest,
    UsersAdvertisementsDeleteRequestTypedDict,
)
from .users_advertisements_enableop import (
    UsersAdvertisementsEnableRequest,
    UsersAdvertisementsEnableRequestTypedDict,
)
from .users_advertisements_getop import (
    UsersAdvertisementsGetRequest,
    UsersAdvertisementsGetRequestTypedDict,
)
from .users_advertisements_listop import (
    UsersAdvertisementsListRequest,
    UsersAdvertisementsListRequestTypedDict,
    UsersAdvertisementsListResponse,
    UsersAdvertisementsListResponseTypedDict,
)
from .users_advertisements_updateop import (
    UsersAdvertisementsUpdateRequest,
    UsersAdvertisementsUpdateRequestTypedDict,
)
from .users_benefits_getop import (
    UsersBenefitsGetRequest,
    UsersBenefitsGetRequestTypedDict,
    UsersBenefitsGetResponseUsersBenefitsGet,
    UsersBenefitsGetResponseUsersBenefitsGetTypedDict,
)
from .users_benefits_listop import (
    BenefitTypeFilter,
    BenefitTypeFilterTypedDict,
    OrderIDFilter,
    OrderIDFilterTypedDict,
    OrganizationIDFilter,
    OrganizationIDFilterTypedDict,
    SubscriptionIDFilter,
    SubscriptionIDFilterTypedDict,
    UsersBenefitsListRequest,
    UsersBenefitsListRequestTypedDict,
    UsersBenefitsListResponse,
    UsersBenefitsListResponseTypedDict,
)
from .users_downloadables_getop import (
    UsersDownloadablesGetRequest,
    UsersDownloadablesGetRequestTypedDict,
)
from .users_downloadables_listop import (
    BenefitIDFilter,
    BenefitIDFilterTypedDict,
    UsersDownloadablesListQueryParamOrganizationIDFilter,
    UsersDownloadablesListQueryParamOrganizationIDFilterTypedDict,
    UsersDownloadablesListRequest,
    UsersDownloadablesListRequestTypedDict,
    UsersDownloadablesListResponse,
    UsersDownloadablesListResponseTypedDict,
)
from .users_license_keys_getop import (
    UsersLicenseKeysGetRequest,
    UsersLicenseKeysGetRequestTypedDict,
)
from .users_license_keys_listop import (
    UsersLicenseKeysListQueryParamOrganizationIDFilter,
    UsersLicenseKeysListQueryParamOrganizationIDFilterTypedDict,
    UsersLicenseKeysListRequest,
    UsersLicenseKeysListRequestTypedDict,
    UsersLicenseKeysListResponse,
    UsersLicenseKeysListResponseTypedDict,
)
from .users_orders_getop import UsersOrdersGetRequest, UsersOrdersGetRequestTypedDict
from .users_orders_invoiceop import (
    UsersOrdersInvoiceRequest,
    UsersOrdersInvoiceRequestTypedDict,
)
from .users_orders_listop import (
    ProductIDFilter,
    ProductIDFilterTypedDict,
    ProductPriceTypeFilter,
    ProductPriceTypeFilterTypedDict,
    QueryParamOrganizationIDFilter,
    QueryParamOrganizationIDFilterTypedDict,
    QueryParamSubscriptionIDFilter,
    QueryParamSubscriptionIDFilterTypedDict,
    UsersOrdersListRequest,
    UsersOrdersListRequestTypedDict,
    UsersOrdersListResponse,
    UsersOrdersListResponseTypedDict,
)
from .users_subscriptions_cancelop import (
    UsersSubscriptionsCancelRequest,
    UsersSubscriptionsCancelRequestTypedDict,
)
from .users_subscriptions_getop import (
    UsersSubscriptionsGetRequest,
    UsersSubscriptionsGetRequestTypedDict,
)
from .users_subscriptions_listop import (
    QueryParamProductIDFilter,
    QueryParamProductIDFilterTypedDict,
    UsersSubscriptionsListQueryParamOrganizationIDFilter,
    UsersSubscriptionsListQueryParamOrganizationIDFilterTypedDict,
    UsersSubscriptionsListRequest,
    UsersSubscriptionsListRequestTypedDict,
    UsersSubscriptionsListResponse,
    UsersSubscriptionsListResponseTypedDict,
)
from .users_subscriptions_updateop import (
    UsersSubscriptionsUpdateRequest,
    UsersSubscriptionsUpdateRequestTypedDict,
)
from .usersubscription import UserSubscription, UserSubscriptionTypedDict
from .usersubscriptionproduct import (
    UserSubscriptionProduct,
    UserSubscriptionProductBenefits,
    UserSubscriptionProductBenefitsTypedDict,
    UserSubscriptionProductTypedDict,
)
from .usersubscriptionsortproperty import UserSubscriptionSortProperty
from .usersubscriptionupdate import (
    UserSubscriptionUpdate,
    UserSubscriptionUpdateTypedDict,
)
from .validatedlicensekey import ValidatedLicenseKey, ValidatedLicenseKeyTypedDict
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .webhookbenefitcreatedpayload import (
    WebhookBenefitCreatedPayload,
    WebhookBenefitCreatedPayloadBenefit,
    WebhookBenefitCreatedPayloadBenefitTypedDict,
    WebhookBenefitCreatedPayloadType,
    WebhookBenefitCreatedPayloadTypedDict,
)
from .webhookbenefitupdatedpayload import (
    WebhookBenefitUpdatedPayload,
    WebhookBenefitUpdatedPayloadBenefit,
    WebhookBenefitUpdatedPayloadBenefitTypedDict,
    WebhookBenefitUpdatedPayloadType,
    WebhookBenefitUpdatedPayloadTypedDict,
)
from .webhookdonationcreatedpayload import (
    WebhookDonationCreatedPayload,
    WebhookDonationCreatedPayloadType,
    WebhookDonationCreatedPayloadTypedDict,
)
from .webhookordercreatedpayload import (
    WebhookOrderCreatedPayload,
    WebhookOrderCreatedPayloadType,
    WebhookOrderCreatedPayloadTypedDict,
)
from .webhookorganizationupdatedpayload import (
    WebhookOrganizationUpdatedPayload,
    WebhookOrganizationUpdatedPayloadType,
    WebhookOrganizationUpdatedPayloadTypedDict,
)
from .webhookpledgecreatedpayload import (
    WebhookPledgeCreatedPayload,
    WebhookPledgeCreatedPayloadType,
    WebhookPledgeCreatedPayloadTypedDict,
)
from .webhookpledgeupdatedpayload import (
    WebhookPledgeUpdatedPayload,
    WebhookPledgeUpdatedPayloadType,
    WebhookPledgeUpdatedPayloadTypedDict,
)
from .webhookproductcreatedpayload import (
    WebhookProductCreatedPayload,
    WebhookProductCreatedPayloadType,
    WebhookProductCreatedPayloadTypedDict,
)
from .webhookproductupdatedpayload import (
    WebhookProductUpdatedPayload,
    WebhookProductUpdatedPayloadType,
    WebhookProductUpdatedPayloadTypedDict,
)
from .webhooksubscriptioncreatedpayload import (
    WebhookSubscriptionCreatedPayload,
    WebhookSubscriptionCreatedPayloadType,
    WebhookSubscriptionCreatedPayloadTypedDict,
)
from .webhooksubscriptionupdatedpayload import (
    WebhookSubscriptionUpdatedPayload,
    WebhookSubscriptionUpdatedPayloadType,
    WebhookSubscriptionUpdatedPayloadTypedDict,
)

__all__ = [
    "AdvertisementCampaign",
    "AdvertisementCampaignListResource",
    "AdvertisementCampaignListResourceTypedDict",
    "AdvertisementCampaignTypedDict",
    "AdvertisementSortProperty",
    "AdvertisementsGetRequest",
    "AdvertisementsGetRequestTypedDict",
    "AdvertisementsListRequest",
    "AdvertisementsListRequestTypedDict",
    "AdvertisementsListResponse",
    "AdvertisementsListResponseTypedDict",
    "AlreadyCanceledSubscription",
    "AlreadyCanceledSubscriptionData",
    "AlreadyCanceledSubscriptionType",
    "AmountType",
    "Article",
    "ArticleByline",
    "ArticleCreate",
    "ArticleCreateArticleByline",
    "ArticleCreateArticleVisibility",
    "ArticleCreateTypedDict",
    "ArticlePreview",
    "ArticlePreviewTypedDict",
    "ArticleReceivers",
    "ArticleReceiversTypedDict",
    "ArticleTypedDict",
    "ArticleUpdate",
    "ArticleUpdateTypedDict",
    "ArticleVisibility",
    "ArticleVisibilityFilter",
    "ArticleVisibilityFilterTypedDict",
    "ArticlesDeleteRequest",
    "ArticlesDeleteRequestTypedDict",
    "ArticlesGetRequest",
    "ArticlesGetRequestTypedDict",
    "ArticlesListQueryParamOrganizationIDFilter",
    "ArticlesListQueryParamOrganizationIDFilterTypedDict",
    "ArticlesListRequest",
    "ArticlesListRequestTypedDict",
    "ArticlesListResponse",
    "ArticlesListResponseTypedDict",
    "ArticlesPreviewRequest",
    "ArticlesPreviewRequestTypedDict",
    "ArticlesReceiversRequest",
    "ArticlesReceiversRequestTypedDict",
    "ArticlesSendRequest",
    "ArticlesSendRequestTypedDict",
    "ArticlesUpdateRequest",
    "ArticlesUpdateRequestTypedDict",
    "Assignee",
    "AssigneeTypedDict",
    "Author",
    "AuthorTypedDict",
    "Benefit",
    "BenefitAds",
    "BenefitAdsCreate",
    "BenefitAdsCreateType",
    "BenefitAdsCreateTypedDict",
    "BenefitAdsProperties",
    "BenefitAdsPropertiesTypedDict",
    "BenefitAdsSubscriber",
    "BenefitAdsSubscriberType",
    "BenefitAdsSubscriberTypedDict",
    "BenefitAdsType",
    "BenefitAdsTypedDict",
    "BenefitAdsUpdate",
    "BenefitAdsUpdateType",
    "BenefitAdsUpdateTypedDict",
    "BenefitArticles",
    "BenefitArticlesProperties",
    "BenefitArticlesPropertiesTypedDict",
    "BenefitArticlesSubscriber",
    "BenefitArticlesSubscriberProperties",
    "BenefitArticlesSubscriberPropertiesTypedDict",
    "BenefitArticlesSubscriberTypedDict",
    "BenefitArticlesType",
    "BenefitArticlesTypedDict",
    "BenefitArticlesUpdate",
    "BenefitArticlesUpdateType",
    "BenefitArticlesUpdateTypedDict",
    "BenefitBase",
    "BenefitBaseTypedDict",
    "BenefitCustom",
    "BenefitCustomCreate",
    "BenefitCustomCreateType",
    "BenefitCustomCreateTypedDict",
    "BenefitCustomProperties",
    "BenefitCustomPropertiesTypedDict",
    "BenefitCustomSubscriber",
    "BenefitCustomSubscriberProperties",
    "BenefitCustomSubscriberPropertiesTypedDict",
    "BenefitCustomSubscriberType",
    "BenefitCustomSubscriberTypedDict",
    "BenefitCustomType",
    "BenefitCustomTypedDict",
    "BenefitCustomUpdate",
    "BenefitCustomUpdateType",
    "BenefitCustomUpdateTypedDict",
    "BenefitDiscordCreate",
    "BenefitDiscordCreateProperties",
    "BenefitDiscordCreatePropertiesTypedDict",
    "BenefitDiscordCreateType",
    "BenefitDiscordCreateTypedDict",
    "BenefitDiscordInput",
    "BenefitDiscordInputType",
    "BenefitDiscordInputTypedDict",
    "BenefitDiscordOutput",
    "BenefitDiscordOutputType",
    "BenefitDiscordOutputTypedDict",
    "BenefitDiscordPropertiesInput",
    "BenefitDiscordPropertiesInputTypedDict",
    "BenefitDiscordPropertiesOutput",
    "BenefitDiscordPropertiesOutputTypedDict",
    "BenefitDiscordSubscriber",
    "BenefitDiscordSubscriberProperties",
    "BenefitDiscordSubscriberPropertiesTypedDict",
    "BenefitDiscordSubscriberType",
    "BenefitDiscordSubscriberTypedDict",
    "BenefitDiscordUpdate",
    "BenefitDiscordUpdateType",
    "BenefitDiscordUpdateTypedDict",
    "BenefitDownloadables",
    "BenefitDownloadablesCreate",
    "BenefitDownloadablesCreateProperties",
    "BenefitDownloadablesCreatePropertiesTypedDict",
    "BenefitDownloadablesCreateType",
    "BenefitDownloadablesCreateTypedDict",
    "BenefitDownloadablesProperties",
    "BenefitDownloadablesPropertiesTypedDict",
    "BenefitDownloadablesSubscriber",
    "BenefitDownloadablesSubscriberProperties",
    "BenefitDownloadablesSubscriberPropertiesTypedDict",
    "BenefitDownloadablesSubscriberType",
    "BenefitDownloadablesSubscriberTypedDict",
    "BenefitDownloadablesType",
    "BenefitDownloadablesTypedDict",
    "BenefitDownloadablesUpdate",
    "BenefitDownloadablesUpdateType",
    "BenefitDownloadablesUpdateTypedDict",
    "BenefitGitHubRepository",
    "BenefitGitHubRepositoryCreate",
    "BenefitGitHubRepositoryCreateProperties",
    "BenefitGitHubRepositoryCreatePropertiesPermission",
    "BenefitGitHubRepositoryCreatePropertiesTypedDict",
    "BenefitGitHubRepositoryCreateType",
    "BenefitGitHubRepositoryCreateTypedDict",
    "BenefitGitHubRepositoryProperties",
    "BenefitGitHubRepositoryPropertiesTypedDict",
    "BenefitGitHubRepositorySubscriber",
    "BenefitGitHubRepositorySubscriberProperties",
    "BenefitGitHubRepositorySubscriberPropertiesTypedDict",
    "BenefitGitHubRepositorySubscriberType",
    "BenefitGitHubRepositorySubscriberTypedDict",
    "BenefitGitHubRepositoryType",
    "BenefitGitHubRepositoryTypedDict",
    "BenefitGitHubRepositoryUpdate",
    "BenefitGitHubRepositoryUpdateType",
    "BenefitGitHubRepositoryUpdateTypedDict",
    "BenefitGrant",
    "BenefitGrantAds",
    "BenefitGrantAdsProperties",
    "BenefitGrantAdsPropertiesTypedDict",
    "BenefitGrantAdsTypedDict",
    "BenefitGrantLicenseKeys",
    "BenefitGrantLicenseKeysProperties",
    "BenefitGrantLicenseKeysPropertiesTypedDict",
    "BenefitGrantLicenseKeysTypedDict",
    "BenefitGrantProperties",
    "BenefitGrantPropertiesTypedDict",
    "BenefitGrantTypedDict",
    "BenefitIDFilter",
    "BenefitIDFilterTypedDict",
    "BenefitLicenseKeyActivationProperties",
    "BenefitLicenseKeyActivationPropertiesTypedDict",
    "BenefitLicenseKeyExpirationProperties",
    "BenefitLicenseKeyExpirationPropertiesTypedDict",
    "BenefitLicenseKeysCreate",
    "BenefitLicenseKeysCreateProperties",
    "BenefitLicenseKeysCreatePropertiesTypedDict",
    "BenefitLicenseKeysCreateType",
    "BenefitLicenseKeysCreateTypedDict",
    "BenefitLicenseKeysInput",
    "BenefitLicenseKeysInputType",
    "BenefitLicenseKeysInputTypedDict",
    "BenefitLicenseKeysOutput",
    "BenefitLicenseKeysOutputType",
    "BenefitLicenseKeysOutputTypedDict",
    "BenefitLicenseKeysProperties",
    "BenefitLicenseKeysPropertiesTypedDict",
    "BenefitLicenseKeysSubscriber",
    "BenefitLicenseKeysSubscriberProperties",
    "BenefitLicenseKeysSubscriberPropertiesTypedDict",
    "BenefitLicenseKeysSubscriberType",
    "BenefitLicenseKeysSubscriberTypedDict",
    "BenefitLicenseKeysUpdate",
    "BenefitLicenseKeysUpdateType",
    "BenefitLicenseKeysUpdateTypedDict",
    "BenefitType",
    "BenefitTypeFilter",
    "BenefitTypeFilterTypedDict",
    "BenefitTypedDict",
    "BenefitsCreateBenefitCreate",
    "BenefitsCreateBenefitCreateTypedDict",
    "BenefitsCreateResponseBenefitsCreate",
    "BenefitsCreateResponseBenefitsCreateTypedDict",
    "BenefitsDeleteRequest",
    "BenefitsDeleteRequestTypedDict",
    "BenefitsGetRequest",
    "BenefitsGetRequestTypedDict",
    "BenefitsGetResponseBenefitsGet",
    "BenefitsGetResponseBenefitsGetTypedDict",
    "BenefitsGrantsRequest",
    "BenefitsGrantsRequestTypedDict",
    "BenefitsGrantsResponse",
    "BenefitsGrantsResponseTypedDict",
    "BenefitsListQueryParamOrganizationIDFilter",
    "BenefitsListQueryParamOrganizationIDFilterTypedDict",
    "BenefitsListRequest",
    "BenefitsListRequestTypedDict",
    "BenefitsListResponse",
    "BenefitsListResponseTypedDict",
    "BenefitsModel",
    "BenefitsModelTypedDict",
    "BenefitsUpdateBenefitUpdate",
    "BenefitsUpdateBenefitUpdateTypedDict",
    "BenefitsUpdateRequest",
    "BenefitsUpdateRequestTypedDict",
    "BenefitsUpdateResponseBenefitsUpdate",
    "BenefitsUpdateResponseBenefitsUpdateTypedDict",
    "BylineProfile",
    "BylineProfileTypedDict",
    "Checkout",
    "CheckoutCreate",
    "CheckoutCreateTypedDict",
    "CheckoutTypedDict",
    "CheckoutsGetRequest",
    "CheckoutsGetRequestTypedDict",
    "Conditions",
    "ConditionsTypedDict",
    "CurrencyAmount",
    "CurrencyAmountTypedDict",
    "DonationInput",
    "DonationInputTypedDict",
    "DonationOrganization",
    "DonationOrganizationTypedDict",
    "DonationUser",
    "DonationUserTypedDict",
    "Donor",
    "DonorTypedDict",
    "DownloadableFileCreate",
    "DownloadableFileCreateService",
    "DownloadableFileCreateTypedDict",
    "DownloadableFileRead",
    "DownloadableFileReadService",
    "DownloadableFileReadTypedDict",
    "DownloadableRead",
    "DownloadableReadTypedDict",
    "ExistingProductPrice",
    "ExistingProductPriceTypedDict",
    "ExternalOrganization",
    "ExternalOrganizationNameFilter",
    "ExternalOrganizationNameFilterTypedDict",
    "ExternalOrganizationSortProperty",
    "ExternalOrganizationTypedDict",
    "ExternalOrganizationsListQueryParamOrganizationIDFilter",
    "ExternalOrganizationsListQueryParamOrganizationIDFilterTypedDict",
    "ExternalOrganizationsListRequest",
    "ExternalOrganizationsListRequestTypedDict",
    "ExternalOrganizationsListResponse",
    "ExternalOrganizationsListResponseTypedDict",
    "FileDownload",
    "FileDownloadTypedDict",
    "FileNotFound",
    "FileNotFoundData",
    "FileNotFoundType",
    "FilePatch",
    "FilePatchTypedDict",
    "FileRead",
    "FileReadTypedDict",
    "FileServiceTypes",
    "FileUpload",
    "FileUploadCompleted",
    "FileUploadCompletedTypedDict",
    "FileUploadTypedDict",
    "FilesCreateFileCreate",
    "FilesCreateFileCreateTypedDict",
    "FilesDeleteRequest",
    "FilesDeleteRequestTypedDict",
    "FilesListRequest",
    "FilesListRequestTypedDict",
    "FilesListResponse",
    "FilesListResponseTypedDict",
    "FilesUpdateRequest",
    "FilesUpdateRequestTypedDict",
    "FilesUpdateResponseFilesUpdate",
    "FilesUpdateResponseFilesUpdateTypedDict",
    "FilesUploadedRequest",
    "FilesUploadedRequestTypedDict",
    "FilesUploadedResponseFilesUploaded",
    "FilesUploadedResponseFilesUploadedTypedDict",
    "Funding",
    "FundingTypedDict",
    "GrantType",
    "GrantTypes",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "Interval",
    "IntrospectTokenResponse",
    "IntrospectTokenResponseTokenType",
    "IntrospectTokenResponseTypedDict",
    "IssueInput",
    "IssueInputTypedDict",
    "Label",
    "LabelTypedDict",
    "LicenseKeyActivate",
    "LicenseKeyActivateConditions",
    "LicenseKeyActivateConditionsTypedDict",
    "LicenseKeyActivateMeta",
    "LicenseKeyActivateMetaTypedDict",
    "LicenseKeyActivateTypedDict",
    "LicenseKeyActivationBase",
    "LicenseKeyActivationBaseTypedDict",
    "LicenseKeyActivationRead",
    "LicenseKeyActivationReadMeta",
    "LicenseKeyActivationReadMetaTypedDict",
    "LicenseKeyActivationReadTypedDict",
    "LicenseKeyDeactivate",
    "LicenseKeyDeactivateTypedDict",
    "LicenseKeyRead",
    "LicenseKeyReadTypedDict",
    "LicenseKeyStatus",
    "LicenseKeyUpdate",
    "LicenseKeyUpdateTypedDict",
    "LicenseKeyValidate",
    "LicenseKeyValidateTypedDict",
    "LicenseKeyWithActivations",
    "LicenseKeyWithActivationsTypedDict",
    "LicenseKeysGetActivationRequest",
    "LicenseKeysGetActivationRequestTypedDict",
    "LicenseKeysGetRequest",
    "LicenseKeysGetRequestTypedDict",
    "LicenseKeysListQueryParamOrganizationIDFilter",
    "LicenseKeysListQueryParamOrganizationIDFilterTypedDict",
    "LicenseKeysListRequest",
    "LicenseKeysListRequestTypedDict",
    "LicenseKeysListResponse",
    "LicenseKeysListResponseTypedDict",
    "LicenseKeysUpdateRequest",
    "LicenseKeysUpdateRequestTypedDict",
    "ListResourceArticle",
    "ListResourceArticleTypedDict",
    "ListResourceBenefit",
    "ListResourceBenefitGrant",
    "ListResourceBenefitGrantTypedDict",
    "ListResourceBenefitTypedDict",
    "ListResourceDownloadableRead",
    "ListResourceDownloadableReadTypedDict",
    "ListResourceExternalOrganization",
    "ListResourceExternalOrganizationTypedDict",
    "ListResourceFileRead",
    "ListResourceFileReadTypedDict",
    "ListResourceLicenseKeyRead",
    "ListResourceLicenseKeyReadTypedDict",
    "ListResourceOAuth2Client",
    "ListResourceOAuth2ClientTypedDict",
    "ListResourceOrder",
    "ListResourceOrderTypedDict",
    "ListResourceOrganization",
    "ListResourceOrganizationTypedDict",
    "ListResourceProduct",
    "ListResourceProductTypedDict",
    "ListResourceRepository",
    "ListResourceRepositoryTypedDict",
    "ListResourceSubscription",
    "ListResourceSubscriptionTypedDict",
    "ListResourceUserAdvertisementCampaign",
    "ListResourceUserAdvertisementCampaignTypedDict",
    "ListResourceUserBenefit",
    "ListResourceUserBenefitTypedDict",
    "ListResourceUserOrder",
    "ListResourceUserOrderTypedDict",
    "ListResourceUserSubscription",
    "ListResourceUserSubscriptionTypedDict",
    "Loc",
    "LocTypedDict",
    "Meta",
    "MetaTypedDict",
    "Metric",
    "MetricPeriod",
    "MetricPeriodTypedDict",
    "MetricType",
    "MetricTypedDict",
    "Metrics",
    "MetricsGetQueryParamOrganizationIDFilter",
    "MetricsGetQueryParamOrganizationIDFilterTypedDict",
    "MetricsGetQueryParamProductIDFilter",
    "MetricsGetQueryParamProductIDFilterTypedDict",
    "MetricsGetQueryParamProductPriceTypeFilter",
    "MetricsGetQueryParamProductPriceTypeFilterTypedDict",
    "MetricsGetRequest",
    "MetricsGetRequestTypedDict",
    "MetricsIntervalLimit",
    "MetricsIntervalLimitTypedDict",
    "MetricsIntervalsLimits",
    "MetricsIntervalsLimitsTypedDict",
    "MetricsLimits",
    "MetricsLimitsTypedDict",
    "MetricsResponse",
    "MetricsResponseTypedDict",
    "MetricsTypedDict",
    "NotPermitted",
    "NotPermittedData",
    "NotPermittedType",
    "OAuth2Client",
    "OAuth2ClientConfiguration",
    "OAuth2ClientConfigurationGrantTypes",
    "OAuth2ClientConfigurationResponseTypes",
    "OAuth2ClientConfigurationTokenEndpointAuthMethod",
    "OAuth2ClientConfigurationTypedDict",
    "OAuth2ClientConfigurationUpdate",
    "OAuth2ClientConfigurationUpdateGrantTypes",
    "OAuth2ClientConfigurationUpdateResponseTypes",
    "OAuth2ClientConfigurationUpdateTokenEndpointAuthMethod",
    "OAuth2ClientConfigurationUpdateTypedDict",
    "OAuth2ClientTypedDict",
    "Oauth2ClientsListRequest",
    "Oauth2ClientsListRequestTypedDict",
    "Oauth2ClientsListResponse",
    "Oauth2ClientsListResponseTypedDict",
    "Oauth2ClientsOauth2DeleteClientRequest",
    "Oauth2ClientsOauth2DeleteClientRequestTypedDict",
    "Oauth2ClientsOauth2GetClientRequest",
    "Oauth2ClientsOauth2GetClientRequestTypedDict",
    "Oauth2ClientsOauth2UpdateClientRequest",
    "Oauth2ClientsOauth2UpdateClientRequestTypedDict",
    "Oauth2IntrospectTokenIntrospectTokenRequest",
    "Oauth2IntrospectTokenIntrospectTokenRequestTypedDict",
    "Oauth2IntrospectTokenTokenTypeHint",
    "Oauth2RequestTokenRequestBody",
    "Oauth2RequestTokenRequestBodyTypedDict",
    "Oauth2RevokeTokenRevokeTokenRequest",
    "Oauth2RevokeTokenRevokeTokenRequestTypedDict",
    "Oauth2UserinfoResponseOauth2Userinfo",
    "Oauth2UserinfoResponseOauth2UserinfoTypedDict",
    "Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequest",
    "Onev11oauth21tokenPostXComponentsAuthorizationCodeTokenRequestTypedDict",
    "Onev11oauth21tokenPostXComponentsRefreshTokenRequest",
    "Onev11oauth21tokenPostXComponentsRefreshTokenRequestGrantType",
    "Onev11oauth21tokenPostXComponentsRefreshTokenRequestTypedDict",
    "OrderIDFilter",
    "OrderIDFilterTypedDict",
    "OrderInput",
    "OrderInputTypedDict",
    "OrderInvoice",
    "OrderInvoiceTypedDict",
    "OrderOutput",
    "OrderOutputTypedDict",
    "OrderProduct",
    "OrderProductTypedDict",
    "OrderSortProperty",
    "OrderSubscription",
    "OrderSubscriptionTypedDict",
    "OrderUser",
    "OrderUserTypedDict",
    "OrdersGetRequest",
    "OrdersGetRequestTypedDict",
    "OrdersInvoiceRequest",
    "OrdersInvoiceRequestTypedDict",
    "OrdersListQueryParamOrganizationIDFilter",
    "OrdersListQueryParamOrganizationIDFilterTypedDict",
    "OrdersListQueryParamProductIDFilter",
    "OrdersListQueryParamProductIDFilterTypedDict",
    "OrdersListRequest",
    "OrdersListRequestTypedDict",
    "OrdersListResponse",
    "OrdersListResponseTypedDict",
    "OrganizationAvatarFileCreate",
    "OrganizationAvatarFileCreateService",
    "OrganizationAvatarFileCreateTypedDict",
    "OrganizationAvatarFileRead",
    "OrganizationAvatarFileReadService",
    "OrganizationAvatarFileReadTypedDict",
    "OrganizationCreate",
    "OrganizationCreateTypedDict",
    "OrganizationFeatureSettings",
    "OrganizationFeatureSettingsTypedDict",
    "OrganizationID",
    "OrganizationIDFilter",
    "OrganizationIDFilterTypedDict",
    "OrganizationIDTypedDict",
    "OrganizationInput",
    "OrganizationInputTypedDict",
    "OrganizationOutput",
    "OrganizationOutputTypedDict",
    "OrganizationProfileSettings",
    "OrganizationProfileSettingsTypedDict",
    "OrganizationSortProperty",
    "OrganizationSubscribePromoteSettings",
    "OrganizationSubscribePromoteSettingsTypedDict",
    "OrganizationUpdate",
    "OrganizationUpdateTypedDict",
    "OrganizationsGetRequest",
    "OrganizationsGetRequestTypedDict",
    "OrganizationsListRequest",
    "OrganizationsListRequestTypedDict",
    "OrganizationsListResponse",
    "OrganizationsListResponseTypedDict",
    "OrganizationsUpdateRequest",
    "OrganizationsUpdateRequestTypedDict",
    "Pagination",
    "PaginationTypedDict",
    "Permission",
    "PlatformFilter",
    "PlatformFilterTypedDict",
    "Platforms",
    "PledgeInput",
    "PledgeInputTypedDict",
    "PledgeState",
    "PledgeType",
    "Pledger",
    "PledgerTypedDict",
    "Prices",
    "PricesTypedDict",
    "ProductBenefitsUpdate",
    "ProductBenefitsUpdateTypedDict",
    "ProductIDFilter",
    "ProductIDFilterTypedDict",
    "ProductInput",
    "ProductInputBenefits",
    "ProductInputBenefitsTypedDict",
    "ProductInputTypedDict",
    "ProductMediaFileCreate",
    "ProductMediaFileCreateService",
    "ProductMediaFileCreateTypedDict",
    "ProductMediaFileReadInput",
    "ProductMediaFileReadInputService",
    "ProductMediaFileReadInputTypedDict",
    "ProductMediaFileReadOutput",
    "ProductMediaFileReadOutputTypedDict",
    "ProductOneTimeCreate",
    "ProductOneTimeCreateTypedDict",
    "ProductOutput",
    "ProductOutputBenefits",
    "ProductOutputBenefitsTypedDict",
    "ProductOutputTypedDict",
    "ProductPriceInput",
    "ProductPriceInputTypedDict",
    "ProductPriceOneTime",
    "ProductPriceOneTimeCustom",
    "ProductPriceOneTimeCustomAmountType",
    "ProductPriceOneTimeCustomCreate",
    "ProductPriceOneTimeCustomCreateAmountType",
    "ProductPriceOneTimeCustomCreateType",
    "ProductPriceOneTimeCustomCreateTypedDict",
    "ProductPriceOneTimeCustomType",
    "ProductPriceOneTimeCustomTypedDict",
    "ProductPriceOneTimeFixed",
    "ProductPriceOneTimeFixedAmountType",
    "ProductPriceOneTimeFixedCreate",
    "ProductPriceOneTimeFixedCreateAmountType",
    "ProductPriceOneTimeFixedCreateType",
    "ProductPriceOneTimeFixedCreateTypedDict",
    "ProductPriceOneTimeFixedType",
    "ProductPriceOneTimeFixedTypedDict",
    "ProductPriceOneTimeFree",
    "ProductPriceOneTimeFreeAmountType",
    "ProductPriceOneTimeFreeCreate",
    "ProductPriceOneTimeFreeCreateAmountType",
    "ProductPriceOneTimeFreeCreateType",
    "ProductPriceOneTimeFreeCreateTypedDict",
    "ProductPriceOneTimeFreeType",
    "ProductPriceOneTimeFreeTypedDict",
    "ProductPriceOneTimeTypedDict",
    "ProductPriceOutput",
    "ProductPriceOutputTypedDict",
    "ProductPriceRecurringCustom",
    "ProductPriceRecurringCustomAmountType",
    "ProductPriceRecurringCustomType",
    "ProductPriceRecurringCustomTypedDict",
    "ProductPriceRecurringFixed",
    "ProductPriceRecurringFixedCreate",
    "ProductPriceRecurringFixedCreateAmountType",
    "ProductPriceRecurringFixedCreateType",
    "ProductPriceRecurringFixedCreateTypedDict",
    "ProductPriceRecurringFixedType",
    "ProductPriceRecurringFixedTypedDict",
    "ProductPriceRecurringFree",
    "ProductPriceRecurringFreeAmountType",
    "ProductPriceRecurringFreeCreate",
    "ProductPriceRecurringFreeCreateAmountType",
    "ProductPriceRecurringFreeCreateType",
    "ProductPriceRecurringFreeCreateTypedDict",
    "ProductPriceRecurringFreeType",
    "ProductPriceRecurringFreeTypedDict",
    "ProductPriceRecurringInput",
    "ProductPriceRecurringInputTypedDict",
    "ProductPriceRecurringOutput",
    "ProductPriceRecurringOutputTypedDict",
    "ProductPriceType",
    "ProductPriceTypeFilter",
    "ProductPriceTypeFilterTypedDict",
    "ProductRecurringCreate",
    "ProductRecurringCreatePrices",
    "ProductRecurringCreatePricesTypedDict",
    "ProductRecurringCreateTypedDict",
    "ProductUpdate",
    "ProductUpdatePrices",
    "ProductUpdatePricesTypedDict",
    "ProductUpdateTypedDict",
    "ProductsCreateProductCreate",
    "ProductsCreateProductCreateTypedDict",
    "ProductsGetRequest",
    "ProductsGetRequestTypedDict",
    "ProductsListQueryParamOrganizationIDFilter",
    "ProductsListQueryParamOrganizationIDFilterTypedDict",
    "ProductsListRequest",
    "ProductsListRequestTypedDict",
    "ProductsListResponse",
    "ProductsListResponseTypedDict",
    "ProductsUpdateBenefitsRequest",
    "ProductsUpdateBenefitsRequestTypedDict",
    "ProductsUpdateRequest",
    "ProductsUpdateRequestTypedDict",
    "QueryParamBenefitIDFilter",
    "QueryParamBenefitIDFilterTypedDict",
    "QueryParamBenefitTypeFilter",
    "QueryParamBenefitTypeFilterTypedDict",
    "QueryParamOrganizationIDFilter",
    "QueryParamOrganizationIDFilterTypedDict",
    "QueryParamPlatformFilter",
    "QueryParamPlatformFilterTypedDict",
    "QueryParamProductIDFilter",
    "QueryParamProductIDFilterTypedDict",
    "QueryParamProductPriceTypeFilter",
    "QueryParamProductPriceTypeFilterTypedDict",
    "QueryParamRepositoryNameFilter",
    "QueryParamRepositoryNameFilterTypedDict",
    "QueryParamSubscriptionIDFilter",
    "QueryParamSubscriptionIDFilterTypedDict",
    "Reactions",
    "ReactionsTypedDict",
    "RepositoriesGetRequest",
    "RepositoriesGetRequestTypedDict",
    "RepositoriesListQueryParamOrganizationIDFilter",
    "RepositoriesListQueryParamOrganizationIDFilterTypedDict",
    "RepositoriesListRequest",
    "RepositoriesListRequestTypedDict",
    "RepositoriesListResponse",
    "RepositoriesListResponseTypedDict",
    "RepositoriesUpdateRequest",
    "RepositoriesUpdateRequestTypedDict",
    "RepositoryInput",
    "RepositoryInputTypedDict",
    "RepositoryNameFilter",
    "RepositoryNameFilterTypedDict",
    "RepositoryOutput",
    "RepositoryOutputTypedDict",
    "RepositoryProfileSettings",
    "RepositoryProfileSettingsTypedDict",
    "RepositoryProfileSettingsUpdate",
    "RepositoryProfileSettingsUpdateTypedDict",
    "RepositorySortProperty",
    "RepositoryUpdate",
    "RepositoryUpdateTypedDict",
    "ResourceNotFound",
    "ResourceNotFoundData",
    "ResourceNotFoundType",
    "ResponseTypes",
    "RevokeTokenResponse",
    "RevokeTokenResponseTypedDict",
    "S3DownloadURL",
    "S3DownloadURLTypedDict",
    "S3FileCreateMultipart",
    "S3FileCreateMultipartTypedDict",
    "S3FileCreatePart",
    "S3FileCreatePartTypedDict",
    "S3FileUploadCompletedPart",
    "S3FileUploadCompletedPartTypedDict",
    "S3FileUploadMultipart",
    "S3FileUploadMultipartTypedDict",
    "S3FileUploadPart",
    "S3FileUploadPartTypedDict",
    "SDKError",
    "Security",
    "SecurityTypedDict",
    "Service",
    "State",
    "SubType",
    "SubscriptionIDFilter",
    "SubscriptionIDFilterTypedDict",
    "SubscriptionInput",
    "SubscriptionInputTypedDict",
    "SubscriptionOutput",
    "SubscriptionOutputTypedDict",
    "SubscriptionRecurringInterval",
    "SubscriptionSortProperty",
    "SubscriptionStatus",
    "SubscriptionUser",
    "SubscriptionUserTypedDict",
    "SubscriptionsExportRequest",
    "SubscriptionsExportRequestTypedDict",
    "SubscriptionsListQueryParamOrganizationIDFilter",
    "SubscriptionsListQueryParamOrganizationIDFilterTypedDict",
    "SubscriptionsListQueryParamProductIDFilter",
    "SubscriptionsListQueryParamProductIDFilterTypedDict",
    "SubscriptionsListRequest",
    "SubscriptionsListRequestTypedDict",
    "SubscriptionsListResponse",
    "SubscriptionsListResponseTypedDict",
    "Timeframe",
    "TokenEndpointAuthMethod",
    "TokenResponse",
    "TokenResponseTypedDict",
    "TokenType",
    "TokenTypeHint",
    "Type",
    "Unauthorized",
    "UnauthorizedData",
    "UnauthorizedType",
    "UserAdvertisementCampaign",
    "UserAdvertisementCampaignCreate",
    "UserAdvertisementCampaignCreateTypedDict",
    "UserAdvertisementCampaignEnable",
    "UserAdvertisementCampaignEnableTypedDict",
    "UserAdvertisementCampaignTypedDict",
    "UserAdvertisementCampaignUpdate",
    "UserAdvertisementCampaignUpdateTypedDict",
    "UserAdvertisementSortProperty",
    "UserBenefit",
    "UserBenefitSortProperty",
    "UserBenefitTypedDict",
    "UserIDFilter",
    "UserIDFilterTypedDict",
    "UserInfoOrganization",
    "UserInfoOrganizationTypedDict",
    "UserInfoUser",
    "UserInfoUserTypedDict",
    "UserOrder",
    "UserOrderInvoice",
    "UserOrderInvoiceTypedDict",
    "UserOrderProduct",
    "UserOrderProductTypedDict",
    "UserOrderSortProperty",
    "UserOrderSubscription",
    "UserOrderSubscriptionTypedDict",
    "UserOrderTypedDict",
    "UserSubscription",
    "UserSubscriptionProduct",
    "UserSubscriptionProductBenefits",
    "UserSubscriptionProductBenefitsTypedDict",
    "UserSubscriptionProductTypedDict",
    "UserSubscriptionSortProperty",
    "UserSubscriptionTypedDict",
    "UserSubscriptionUpdate",
    "UserSubscriptionUpdateTypedDict",
    "UsersAdvertisementsDeleteRequest",
    "UsersAdvertisementsDeleteRequestTypedDict",
    "UsersAdvertisementsEnableRequest",
    "UsersAdvertisementsEnableRequestTypedDict",
    "UsersAdvertisementsGetRequest",
    "UsersAdvertisementsGetRequestTypedDict",
    "UsersAdvertisementsListRequest",
    "UsersAdvertisementsListRequestTypedDict",
    "UsersAdvertisementsListResponse",
    "UsersAdvertisementsListResponseTypedDict",
    "UsersAdvertisementsUpdateRequest",
    "UsersAdvertisementsUpdateRequestTypedDict",
    "UsersBenefitsGetRequest",
    "UsersBenefitsGetRequestTypedDict",
    "UsersBenefitsGetResponseUsersBenefitsGet",
    "UsersBenefitsGetResponseUsersBenefitsGetTypedDict",
    "UsersBenefitsListRequest",
    "UsersBenefitsListRequestTypedDict",
    "UsersBenefitsListResponse",
    "UsersBenefitsListResponseTypedDict",
    "UsersDownloadablesGetRequest",
    "UsersDownloadablesGetRequestTypedDict",
    "UsersDownloadablesListQueryParamOrganizationIDFilter",
    "UsersDownloadablesListQueryParamOrganizationIDFilterTypedDict",
    "UsersDownloadablesListRequest",
    "UsersDownloadablesListRequestTypedDict",
    "UsersDownloadablesListResponse",
    "UsersDownloadablesListResponseTypedDict",
    "UsersLicenseKeysGetRequest",
    "UsersLicenseKeysGetRequestTypedDict",
    "UsersLicenseKeysListQueryParamOrganizationIDFilter",
    "UsersLicenseKeysListQueryParamOrganizationIDFilterTypedDict",
    "UsersLicenseKeysListRequest",
    "UsersLicenseKeysListRequestTypedDict",
    "UsersLicenseKeysListResponse",
    "UsersLicenseKeysListResponseTypedDict",
    "UsersOrdersGetRequest",
    "UsersOrdersGetRequestTypedDict",
    "UsersOrdersInvoiceRequest",
    "UsersOrdersInvoiceRequestTypedDict",
    "UsersOrdersListRequest",
    "UsersOrdersListRequestTypedDict",
    "UsersOrdersListResponse",
    "UsersOrdersListResponseTypedDict",
    "UsersSubscriptionsCancelRequest",
    "UsersSubscriptionsCancelRequestTypedDict",
    "UsersSubscriptionsGetRequest",
    "UsersSubscriptionsGetRequestTypedDict",
    "UsersSubscriptionsListQueryParamOrganizationIDFilter",
    "UsersSubscriptionsListQueryParamOrganizationIDFilterTypedDict",
    "UsersSubscriptionsListRequest",
    "UsersSubscriptionsListRequestTypedDict",
    "UsersSubscriptionsListResponse",
    "UsersSubscriptionsListResponseTypedDict",
    "UsersSubscriptionsUpdateRequest",
    "UsersSubscriptionsUpdateRequestTypedDict",
    "ValidatedLicenseKey",
    "ValidatedLicenseKeyTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "WebhookBenefitCreatedPayload",
    "WebhookBenefitCreatedPayloadBenefit",
    "WebhookBenefitCreatedPayloadBenefitTypedDict",
    "WebhookBenefitCreatedPayloadType",
    "WebhookBenefitCreatedPayloadTypedDict",
    "WebhookBenefitUpdatedPayload",
    "WebhookBenefitUpdatedPayloadBenefit",
    "WebhookBenefitUpdatedPayloadBenefitTypedDict",
    "WebhookBenefitUpdatedPayloadType",
    "WebhookBenefitUpdatedPayloadTypedDict",
    "WebhookDonationCreatedPayload",
    "WebhookDonationCreatedPayloadType",
    "WebhookDonationCreatedPayloadTypedDict",
    "WebhookOrderCreatedPayload",
    "WebhookOrderCreatedPayloadType",
    "WebhookOrderCreatedPayloadTypedDict",
    "WebhookOrganizationUpdatedPayload",
    "WebhookOrganizationUpdatedPayloadType",
    "WebhookOrganizationUpdatedPayloadTypedDict",
    "WebhookPledgeCreatedPayload",
    "WebhookPledgeCreatedPayloadType",
    "WebhookPledgeCreatedPayloadTypedDict",
    "WebhookPledgeUpdatedPayload",
    "WebhookPledgeUpdatedPayloadType",
    "WebhookPledgeUpdatedPayloadTypedDict",
    "WebhookProductCreatedPayload",
    "WebhookProductCreatedPayloadType",
    "WebhookProductCreatedPayloadTypedDict",
    "WebhookProductUpdatedPayload",
    "WebhookProductUpdatedPayloadType",
    "WebhookProductUpdatedPayloadTypedDict",
    "WebhookSubscriptionCreatedPayload",
    "WebhookSubscriptionCreatedPayloadType",
    "WebhookSubscriptionCreatedPayloadTypedDict",
    "WebhookSubscriptionUpdatedPayload",
    "WebhookSubscriptionUpdatedPayloadType",
    "WebhookSubscriptionUpdatedPayloadTypedDict",
]
