"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .product_input import ProductInput, ProductInputTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
import pydantic
from typing import Final, TypedDict
from typing_extensions import Annotated


class WebhookProductUpdatedPayloadType(str, Enum):
    PRODUCT_UPDATED = "product.updated"


class WebhookProductUpdatedPayloadTypedDict(TypedDict):
    r"""Sent when a product is updated.

    **Discord & Slack support:** Basic
    """

    data: ProductInputTypedDict
    r"""A product."""
    type: WebhookProductUpdatedPayloadType


class WebhookProductUpdatedPayload(BaseModel):
    r"""Sent when a product is updated.

    **Discord & Slack support:** Basic
    """

    data: ProductInput
    r"""A product."""

    # fmt: off
    TYPE: Annotated[Final[WebhookProductUpdatedPayloadType], pydantic.Field(alias="type")] = WebhookProductUpdatedPayloadType.PRODUCT_UPDATED # type: ignore
    # fmt: on
