"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class ExistingProductPriceTypedDict(TypedDict):
    r"""A price that already exists for this product.

    Useful when updating a product if you want to keep an existing price.
    """

    id: str


class ExistingProductPrice(BaseModel):
    r"""A price that already exists for this product.

    Useful when updating a product if you want to keep an existing price.
    """

    id: str
