"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk import utils
from polar_sdk.types import BaseModel
import pydantic
from typing import Final
from typing_extensions import Annotated


class NotPermittedType(str, Enum):
    NOT_PERMITTED = "NotPermitted"


class NotPermittedData(BaseModel):
    detail: str

    # fmt: off
    TYPE: Annotated[Final[NotPermittedType], pydantic.Field(alias="type")] = NotPermittedType.NOT_PERMITTED # type: ignore
    # fmt: on


class NotPermitted(Exception):
    r"""You don't have the permission to update this repository."""

    data: NotPermittedData

    def __init__(self, data: NotPermittedData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, NotPermittedData)
