"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .userorder import UserOrder, UserOrderTypedDict
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class ListResourceUserOrderTypedDict(TypedDict):
    items: List[UserOrderTypedDict]
    pagination: PaginationTypedDict


class ListResourceUserOrder(BaseModel):
    items: List[UserOrder]

    pagination: Pagination
