"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .article import Article, ArticleTypedDict
from .pagination import Pagination, PaginationTypedDict
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class ListResourceArticleTypedDict(TypedDict):
    items: List[ArticleTypedDict]
    pagination: PaginationTypedDict


class ListResourceArticle(BaseModel):
    items: List[Article]

    pagination: Pagination
