"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class RevokeTokenResponseTypedDict(TypedDict):
    pass


class RevokeTokenResponse(BaseModel):
    pass
