"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class LabelTypedDict(TypedDict):
    name: str
    color: str


class Label(BaseModel):
    name: str

    color: str
