"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class PaginationTypedDict(TypedDict):
    total_count: int
    max_page: int


class Pagination(BaseModel):
    total_count: int

    max_page: int
