"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .product_output import ProductOutput, ProductOutputTypedDict
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class ListResourceProductTypedDict(TypedDict):
    items: List[ProductOutputTypedDict]
    pagination: PaginationTypedDict


class ListResourceProduct(BaseModel):
    items: List[ProductOutput]

    pagination: Pagination
