"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organization_input import OrganizationInput, OrganizationInputTypedDict
from enum import Enum
from polar_sdk.types import BaseModel
import pydantic
from typing import Final, TypedDict
from typing_extensions import Annotated


class WebhookOrganizationUpdatedPayloadType(str, Enum):
    ORGANIZATION_UPDATED = "organization.updated"


class WebhookOrganizationUpdatedPayloadTypedDict(TypedDict):
    r"""Sent when a organization is updated.

    **Discord & Slack support:** Basic
    """

    data: OrganizationInputTypedDict
    type: WebhookOrganizationUpdatedPayloadType


class WebhookOrganizationUpdatedPayload(BaseModel):
    r"""Sent when a organization is updated.

    **Discord & Slack support:** Basic
    """

    data: OrganizationInput

    # fmt: off
    TYPE: Annotated[Final[WebhookOrganizationUpdatedPayloadType], pydantic.Field(alias="type")] = WebhookOrganizationUpdatedPayloadType.ORGANIZATION_UPDATED # type: ignore
    # fmt: on
