"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class ProductBenefitsUpdateTypedDict(TypedDict):
    r"""Schema to update the benefits granted by a product."""

    benefits: List[str]
    r"""List of benefit IDs. Each one must be on the same organization as the product."""


class ProductBenefitsUpdate(BaseModel):
    r"""Schema to update the benefits granted by a product."""

    benefits: List[str]
    r"""List of benefit IDs. Each one must be on the same organization as the product."""
