"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .s3fileuploadcompletedpart import (
    S3FileUploadCompletedPart,
    S3FileUploadCompletedPartTypedDict,
)
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class FileUploadCompletedTypedDict(TypedDict):
    id: str
    path: str
    parts: List[S3FileUploadCompletedPartTypedDict]


class FileUploadCompleted(BaseModel):
    id: str

    path: str

    parts: List[S3FileUploadCompletedPart]
