"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class BenefitGrantLicenseKeysPropertiesTypedDict(TypedDict):
    license_key_id: str
    display_key: str


class BenefitGrantLicenseKeysProperties(BaseModel):
    license_key_id: str

    display_key: str
