"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import TypedDict


class UserSubscriptionUpdateTypedDict(TypedDict):
    product_price_id: str


class UserSubscriptionUpdate(BaseModel):
    product_price_id: str
