"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .usersubscriptionupdate import (
    UserSubscriptionUpdate,
    UserSubscriptionUpdateTypedDict,
)
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import TypedDict
from typing_extensions import Annotated


class UsersSubscriptionsUpdateRequestTypedDict(TypedDict):
    id: str
    r"""The subscription ID."""
    user_subscription_update: UserSubscriptionUpdateTypedDict


class UsersSubscriptionsUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The subscription ID."""

    user_subscription_update: Annotated[
        UserSubscriptionUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
