"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .repository_output import RepositoryOutput, RepositoryOutputTypedDict
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class ListResourceRepositoryTypedDict(TypedDict):
    items: List[RepositoryOutputTypedDict]
    pagination: PaginationTypedDict


class ListResourceRepository(BaseModel):
    items: List[RepositoryOutput]

    pagination: Pagination
