"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productpriceonetime import ProductPriceOneTime, ProductPriceOneTimeTypedDict
from .productpricerecurring_input import (
    ProductPriceRecurringInput,
    ProductPriceRecurringInputTypedDict,
)
from typing import Union


ProductPriceInputTypedDict = Union[
    ProductPriceRecurringInputTypedDict, ProductPriceOneTimeTypedDict
]


ProductPriceInput = Union[ProductPriceRecurringInput, ProductPriceOneTime]
