"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .usersubscription import UserSubscription, UserSubscriptionTypedDict
from polar_sdk.types import BaseModel
from typing import List, TypedDict


class ListResourceUserSubscriptionTypedDict(TypedDict):
    items: List[UserSubscriptionTypedDict]
    pagination: PaginationTypedDict


class ListResourceUserSubscription(BaseModel):
    items: List[UserSubscription]

    pagination: Pagination
