"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UserBenefitSortProperty(str, Enum):
    GRANTED_AT = "granted_at"
    MINUS_GRANTED_AT = "-granted_at"
    TYPE = "type"
    MINUS_TYPE = "-type"
    ORGANIZATION = "organization"
    MINUS_ORGANIZATION = "-organization"
