"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk import utils
from polar_sdk.types import BaseModel
import pydantic
from typing import Final
from typing_extensions import Annotated


class AlreadyCanceledSubscriptionType(str, Enum):
    ALREADY_CANCELED_SUBSCRIPTION = "AlreadyCanceledSubscription"


class AlreadyCanceledSubscriptionData(BaseModel):
    detail: str

    # fmt: off
    TYPE: Annotated[Final[AlreadyCanceledSubscriptionType], pydantic.Field(alias="type")] = AlreadyCanceledSubscriptionType.ALREADY_CANCELED_SUBSCRIPTION # type: ignore
    # fmt: on


class AlreadyCanceledSubscription(Exception):
    data: AlreadyCanceledSubscriptionData

    def __init__(self, data: AlreadyCanceledSubscriptionData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, AlreadyCanceledSubscriptionData)
